from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.BRepClass3d import *
from OCC.Core.TopTools import *
from OCC.Core.TopoDS import *
from OCC.Core.TopAbs import *
from OCC.Core.Bnd import *
from OCC.Core.TColStd import *
from OCC.Core.Geom2d import *
from OCC.Core.GeomAdaptor import *
from OCC.Core.Geom import *
from OCC.Core.TColgp import *
from OCC.Core.gp import *
from OCC.Core.TopExp import *
from OCC.Core.BRepAdaptor import *
from OCC.Core.TCollection import *
from OCC.Core.GeomAbs import *
from OCC.Core.Extrema import *

#the following typedef cannot be wrapped as is
TopOpeBRepTool_IndexedDataMapOfShapeBox = NewType('TopOpeBRepTool_IndexedDataMapOfShapeBox', Any)
#the following typedef cannot be wrapped as is
TopOpeBRepTool_IndexedDataMapOfShapeBox2d = NewType('TopOpeBRepTool_IndexedDataMapOfShapeBox2d', Any)
#the following typedef cannot be wrapped as is
TopOpeBRepTool_IndexedDataMapOfShapeconnexity = NewType('TopOpeBRepTool_IndexedDataMapOfShapeconnexity', Any)
TopOpeBRepTool_PShapeClassifier = NewType('TopOpeBRepTool_PShapeClassifier', TopOpeBRepTool_ShapeClassifier)
TopOpeBRepTool_PSoClassif = NewType('TopOpeBRepTool_PSoClassif', BRepClass3d_SolidClassifier)
TopOpeBRepTool_Plos = NewType('TopOpeBRepTool_Plos', TopTools_ListOfShape)

class TopOpeBRepTool_ListOfC2DF:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> TopOpeBRepTool_C2DF: ...
    def Last(self) -> TopOpeBRepTool_C2DF: ...
    def Append(self, theItem: TopOpeBRepTool_C2DF) -> TopOpeBRepTool_C2DF: ...
    def Prepend(self, theItem: TopOpeBRepTool_C2DF) -> TopOpeBRepTool_C2DF: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> TopOpeBRepTool_C2DF: ...
    def SetValue(self, theIndex: int, theValue: TopOpeBRepTool_C2DF) -> None: ...

class TopOpeBRepTool_OutCurveType(IntEnum):
	TopOpeBRepTool_BSPLINE1: int = ...
	TopOpeBRepTool_APPROX: int = ...
	TopOpeBRepTool_INTERPOL: int = ...
TopOpeBRepTool_BSPLINE1 = TopOpeBRepTool_OutCurveType.TopOpeBRepTool_BSPLINE1
TopOpeBRepTool_APPROX = TopOpeBRepTool_OutCurveType.TopOpeBRepTool_APPROX
TopOpeBRepTool_INTERPOL = TopOpeBRepTool_OutCurveType.TopOpeBRepTool_INTERPOL

class topopebreptool:
	@staticmethod
	def CorrectONUVISO(F: TopoDS_Face, Fsp: TopoDS_Face) -> bool: ...
	@staticmethod
	def MakeFaces(F: TopoDS_Face, LOF: TopTools_ListOfShape, MshNOK: TopTools_IndexedMapOfOrientedShape, LOFF: TopTools_ListOfShape) -> bool: ...
	@overload
	@staticmethod
	def PurgeClosingEdges(F: TopoDS_Face, FF: TopoDS_Face, MWisOld: TopTools_DataMapOfShapeInteger, MshNOK: TopTools_IndexedMapOfOrientedShape) -> bool: ...
	@overload
	@staticmethod
	def PurgeClosingEdges(F: TopoDS_Face, LOF: TopTools_ListOfShape, MWisOld: TopTools_DataMapOfShapeInteger, MshNOK: TopTools_IndexedMapOfOrientedShape) -> bool: ...
	@staticmethod
	def Regularize(aFace: TopoDS_Face, aListOfFaces: TopTools_ListOfShape, ESplits: TopTools_DataMapOfShapeListOfShape) -> bool: ...
	@staticmethod
	def RegularizeFace(aFace: TopoDS_Face, OldWiresnewWires: TopTools_DataMapOfShapeListOfShape, aListOfFaces: TopTools_ListOfShape) -> bool: ...
	@staticmethod
	def RegularizeShells(aSolid: TopoDS_Solid, OldSheNewShe: TopTools_DataMapOfShapeListOfShape, FSplits: TopTools_DataMapOfShapeListOfShape) -> bool: ...
	@staticmethod
	def RegularizeWires(aFace: TopoDS_Face, OldWiresNewWires: TopTools_DataMapOfShapeListOfShape, ESplits: TopTools_DataMapOfShapeListOfShape) -> bool: ...

class TopOpeBRepTool_AncestorsTool:
	@staticmethod
	def MakeAncestors(S: TopoDS_Shape, TS: TopAbs_ShapeEnum, TA: TopAbs_ShapeEnum, M: TopTools_IndexedDataMapOfShapeListOfShape) -> None: ...

class TopOpeBRepTool_BoxSort:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, T: TopOpeBRepTool_HBoxTool) -> None: ...
	def AddBoxes(self, S: TopoDS_Shape, TS: TopAbs_ShapeEnum, TA: Optional[TopAbs_ShapeEnum] = TopAbs_SHAPE) -> None: ...
	def AddBoxesMakeCOB(self, S: TopoDS_Shape, TS: TopAbs_ShapeEnum, TA: Optional[TopAbs_ShapeEnum] = TopAbs_SHAPE) -> None: ...
	def Box(self, S: TopoDS_Shape) -> Bnd_Box: ...
	def Clear(self) -> None: ...
	def Compare(self, S: TopoDS_Shape) -> TColStd_ListIteratorOfListOfInteger: ...
	def HAB(self) -> Bnd_HArray1OfBox: ...
	def HABShape(self, I: int) -> TopoDS_Shape: ...
	def HBoxTool(self) -> TopOpeBRepTool_HBoxTool: ...
	def MakeCOB(self, S: TopoDS_Shape, TS: TopAbs_ShapeEnum, TA: Optional[TopAbs_ShapeEnum] = TopAbs_SHAPE) -> None: ...
	def MakeHAB(self, S: TopoDS_Shape, TS: TopAbs_ShapeEnum, TA: Optional[TopAbs_ShapeEnum] = TopAbs_SHAPE) -> None: ...
	@staticmethod
	def MakeHABCOB(HAB: Bnd_HArray1OfBox, COB: Bnd_Box) -> None: ...
	def SetHBoxTool(self, T: TopOpeBRepTool_HBoxTool) -> None: ...
	def TouchedShape(self, I: TColStd_ListIteratorOfListOfInteger) -> TopoDS_Shape: ...

class TopOpeBRepTool_C2DF:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, PC: Geom2d_Curve, f2d: float, l2d: float, tol: float, F: TopoDS_Face) -> None: ...
	def Face(self) -> TopoDS_Face: ...
	def IsFace(self, F: TopoDS_Face) -> bool: ...
	def IsPC(self, PC: Geom2d_Curve) -> bool: ...
	def PC(self) -> Tuple[Geom2d_Curve, float, float, float]: ...
	def SetFace(self, F: TopoDS_Face) -> None: ...
	def SetPC(self, PC: Geom2d_Curve, f2d: float, l2d: float, tol: float) -> None: ...

class TopOpeBRepTool_CLASSI:
	def __init__(self) -> None: ...
	def Add2d(self, S: TopoDS_Shape) -> bool: ...
	def ClassiBnd2d(self, S1: TopoDS_Shape, S2: TopoDS_Shape, tol: float, checklarge: bool) -> int: ...
	def Classilist(self, lS: TopTools_ListOfShape, mapgreasma: TopTools_DataMapOfShapeListOfShape) -> bool: ...
	def Classip2d(self, S1: TopoDS_Shape, S2: TopoDS_Shape, stabnd2d12: int) -> int: ...
	def GetBox2d(self, S: TopoDS_Shape, Box2d: Bnd_Box2d) -> bool: ...
	def Getface(self, S: TopoDS_Shape, fa: TopOpeBRepTool_face) -> bool: ...
	def HasInit2d(self) -> bool: ...
	def Init2d(self, Fref: TopoDS_Face) -> None: ...

class TopOpeBRepTool_CORRISO:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, FRef: TopoDS_Face) -> None: ...
	def AddNewConnexity(self, V: TopoDS_Vertex, E: TopoDS_Edge) -> bool: ...
	def Connexity(self, V: TopoDS_Vertex, Eds: TopTools_ListOfShape) -> bool: ...
	def EdgeOUTofBoundsUV(self, E: TopoDS_Edge, onU: bool, tolx: float) -> Tuple[int, float]: ...
	@overload
	def EdgeWithFaultyUV(self, E: TopoDS_Edge) -> Tuple[bool, int]: ...
	@overload
	def EdgeWithFaultyUV(self, EdsToCheck: TopTools_ListOfShape, nfybounds: int, fyE: TopoDS_Shape) -> Tuple[bool, int]: ...
	def EdgesOUTofBoundsUV(self, EdsToCheck: TopTools_ListOfShape, onU: bool, tolx: float, FyEds: TopTools_DataMapOfOrientedShapeInteger) -> bool: ...
	def EdgesWithFaultyUV(self, EdsToCheck: TopTools_ListOfShape, nfybounds: int, FyEds: TopTools_DataMapOfOrientedShapeInteger, stopatfirst: Optional[bool] = False) -> bool: ...
	def Eds(self) -> TopTools_ListOfShape: ...
	def Fref(self) -> TopoDS_Face: ...
	def GASref(self) -> GeomAdaptor_Surface: ...
	def GetnewS(self, newS: TopoDS_Face) -> bool: ...
	def Init(self, S: TopoDS_Shape) -> bool: ...
	def PurgeFyClosingE(self, ClEds: TopTools_ListOfShape, fyClEds: TopTools_ListOfShape) -> bool: ...
	def Refclosed(self, x: int) -> Tuple[bool, float]: ...
	def RemoveOldConnexity(self, V: TopoDS_Vertex, E: TopoDS_Edge) -> bool: ...
	def S(self) -> TopoDS_Shape: ...
	def SetConnexity(self, V: TopoDS_Vertex, Eds: TopTools_ListOfShape) -> bool: ...
	def SetUVRep(self, E: TopoDS_Edge, C2DF: TopOpeBRepTool_C2DF) -> bool: ...
	def Tol(self, I: int, tol3d: float) -> float: ...
	def TrslUV(self, onU: bool, FyEds: TopTools_DataMapOfOrientedShapeInteger) -> bool: ...
	def UVClosed(self) -> bool: ...
	def UVRep(self, E: TopoDS_Edge, C2DF: TopOpeBRepTool_C2DF) -> bool: ...

class TopOpeBRepTool_CurveTool:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, OCT: TopOpeBRepTool_OutCurveType) -> None: ...
	@overload
	def __init__(self, GT: TopOpeBRepTool_GeomTool) -> None: ...
	def ChangeGeomTool(self) -> TopOpeBRepTool_GeomTool: ...
	def GetGeomTool(self) -> TopOpeBRepTool_GeomTool: ...
	@staticmethod
	def IsProjectable(S: TopoDS_Shape, C: Geom_Curve) -> bool: ...
	@staticmethod
	def MakeBSpline1fromPnt(P: TColgp_Array1OfPnt) -> Geom_Curve: ...
	@staticmethod
	def MakeBSpline1fromPnt2d(P: TColgp_Array1OfPnt2d) -> Geom2d_Curve: ...
	def MakeCurves(self, min: float, max: float, C3D: Geom_Curve, PC1: Geom2d_Curve, PC2: Geom2d_Curve, S1: TopoDS_Shape, S2: TopoDS_Shape, C3DN: Geom_Curve, PC1N: Geom2d_Curve, PC2N: Geom2d_Curve) -> Tuple[bool, float, float]: ...
	@staticmethod
	def MakePCurveOnFace(S: TopoDS_Shape, C: Geom_Curve, first: Optional[float] = 0.0, last: Optional[float] = 0.0) -> Tuple[Geom2d_Curve, float]: ...
	def SetGeomTool(self, GT: TopOpeBRepTool_GeomTool) -> None: ...

class TopOpeBRepTool_FuseEdges:
	def __init__(self, theShape: TopoDS_Shape, PerformNow: Optional[bool] = False) -> None: ...
	def AvoidEdges(self, theMapEdg: TopTools_IndexedMapOfShape) -> None: ...
	def Edges(self, theMapLstEdg: TopTools_DataMapOfIntegerListOfShape) -> None: ...
	def Faces(self, theMapFac: TopTools_DataMapOfShapeShape) -> None: ...
	def NbVertices(self) -> int: ...
	def Perform(self) -> None: ...
	def ResultEdges(self, theMapEdg: TopTools_DataMapOfIntegerShape) -> None: ...
	def Shape(self) -> TopoDS_Shape: ...

class TopOpeBRepTool_GeomTool:
	def __init__(self, TypeC3D: Optional[TopOpeBRepTool_OutCurveType] = TopOpeBRepTool_BSPLINE1, CompC3D: Optional[bool] = True, CompPC1: Optional[bool] = True, CompPC2: Optional[bool] = True) -> None: ...
	def CompC3D(self) -> bool: ...
	def CompPC1(self) -> bool: ...
	def CompPC2(self) -> bool: ...
	@overload
	def Define(self, TypeC3D: TopOpeBRepTool_OutCurveType, CompC3D: bool, CompPC1: bool, CompPC2: bool) -> None: ...
	@overload
	def Define(self, TypeC3D: TopOpeBRepTool_OutCurveType) -> None: ...
	@overload
	def Define(self, GT: TopOpeBRepTool_GeomTool) -> None: ...
	def DefineCurves(self, CompC3D: bool) -> None: ...
	def DefinePCurves1(self, CompPC1: bool) -> None: ...
	def DefinePCurves2(self, CompPC2: bool) -> None: ...
	def GetTolerances(self) -> Tuple[float, float]: ...
	def NbPntMax(self) -> int: ...
	def SetNbPntMax(self, NbPntMax: int) -> None: ...
	def SetTolerances(self, tol3d: float, tol2d: float) -> None: ...
	def TypeC3D(self) -> TopOpeBRepTool_OutCurveType: ...

class TopOpeBRepTool_HBoxTool(Standard_Transient):
	def __init__(self) -> None: ...
	def AddBox(self, S: TopoDS_Shape) -> None: ...
	def AddBoxes(self, S: TopoDS_Shape, TS: TopAbs_ShapeEnum, TA: Optional[TopAbs_ShapeEnum] = TopAbs_SHAPE) -> None: ...
	@overload
	def Box(self, S: TopoDS_Shape) -> Bnd_Box: ...
	@overload
	def Box(self, I: int) -> Bnd_Box: ...
	def ChangeIMS(self) -> TopOpeBRepTool_IndexedDataMapOfShapeBox: ...
	def Clear(self) -> None: ...
	@staticmethod
	def ComputeBox(S: TopoDS_Shape, B: Bnd_Box) -> None: ...
	@staticmethod
	def ComputeBoxOnVertices(S: TopoDS_Shape, B: Bnd_Box) -> None: ...
	@staticmethod
	def DumpB(B: Bnd_Box) -> None: ...
	def Extent(self) -> int: ...
	def HasBox(self, S: TopoDS_Shape) -> bool: ...
	def IMS(self) -> TopOpeBRepTool_IndexedDataMapOfShapeBox: ...
	def Index(self, S: TopoDS_Shape) -> int: ...
	def Shape(self, I: int) -> TopoDS_Shape: ...

class TopOpeBRepTool_PurgeInternalEdges:
	def __init__(self, theShape: TopoDS_Shape, PerformNow: Optional[bool] = True) -> None: ...
	def Faces(self, theMapFacLstEdg: TopTools_DataMapOfShapeListOfShape) -> None: ...
	def IsDone(self) -> bool: ...
	def NbEdges(self) -> int: ...
	def Perform(self) -> None: ...
	def Shape(self) -> TopoDS_Shape: ...

class TopOpeBRepTool_REGUS:
	def __init__(self) -> None: ...
	def GetFsplits(self, Fsplits: TopTools_DataMapOfShapeListOfShape) -> None: ...
	def GetOshNsh(self, OshNsh: TopTools_DataMapOfShapeListOfShape) -> None: ...
	def Init(self, S: TopoDS_Shape) -> None: ...
	def InitBlock(self) -> bool: ...
	def MapS(self) -> bool: ...
	def NearestF(self, e: TopoDS_Edge, lof: TopTools_ListOfShape, ffound: TopoDS_Face) -> bool: ...
	def NextinBlock(self) -> bool: ...
	def REGU(self) -> bool: ...
	def S(self) -> TopoDS_Shape: ...
	def SetFsplits(self, Fsplits: TopTools_DataMapOfShapeListOfShape) -> None: ...
	def SetOshNsh(self, OshNsh: TopTools_DataMapOfShapeListOfShape) -> None: ...
	@staticmethod
	def SplitF(Fanc: TopoDS_Face, FSplits: TopTools_ListOfShape) -> bool: ...
	def SplitFaces(self) -> bool: ...
	@staticmethod
	def WireToFace(Fanc: TopoDS_Face, nWs: TopTools_ListOfShape, nFs: TopTools_ListOfShape) -> bool: ...

class TopOpeBRepTool_REGUW:
	def __init__(self, FRef: TopoDS_Face) -> None: ...
	def AddNewConnexity(self, v: TopoDS_Vertex, OriKey: int, e: TopoDS_Edge) -> bool: ...
	def Connexity(self, v: TopoDS_Vertex, co: TopOpeBRepTool_connexity) -> bool: ...
	def Fref(self) -> TopoDS_Face: ...
	def GetEsplits(self, Esplits: TopTools_DataMapOfShapeListOfShape) -> None: ...
	def GetOwNw(self, OwNw: TopTools_DataMapOfShapeListOfShape) -> None: ...
	def GetSplits(self, Splits: TopTools_ListOfShape) -> bool: ...
	def HasInit(self) -> bool: ...
	def Init(self, S: TopoDS_Shape) -> None: ...
	def InitBlock(self) -> bool: ...
	def MapS(self) -> bool: ...
	def NearestE(self, loe: TopTools_ListOfShape, efound: TopoDS_Edge) -> bool: ...
	def NextinBlock(self) -> bool: ...
	@overload
	def REGU(self, istep: int, Scur: TopoDS_Shape, Splits: TopTools_ListOfShape) -> bool: ...
	@overload
	def REGU(self) -> bool: ...
	def RemoveOldConnexity(self, v: TopoDS_Vertex, OriKey: int, e: TopoDS_Edge) -> bool: ...
	def S(self) -> TopoDS_Shape: ...
	def SetEsplits(self, Esplits: TopTools_DataMapOfShapeListOfShape) -> None: ...
	def SetOwNw(self, OwNw: TopTools_DataMapOfShapeListOfShape) -> None: ...
	def SplitEds(self) -> bool: ...
	def UpdateMultiple(self, v: TopoDS_Vertex) -> bool: ...

class TopOpeBRepTool_ShapeClassifier:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, SRef: TopoDS_Shape) -> None: ...
	def ChangeSolidClassifier(self) -> TopOpeBRepTool_SolidClassifier: ...
	def ClearAll(self) -> None: ...
	def ClearCurrent(self) -> None: ...
	def P2D(self) -> gp_Pnt2d: ...
	def P3D(self) -> gp_Pnt: ...
	@overload
	def SameDomain(self) -> int: ...
	@overload
	def SameDomain(self, samedomain: int) -> None: ...
	def SetReference(self, SRef: TopoDS_Shape) -> None: ...
	def State(self) -> TopAbs_State: ...
	def StateP2DReference(self, P2D: gp_Pnt2d) -> None: ...
	def StateP3DReference(self, P3D: gp_Pnt) -> None: ...
	@overload
	def StateShapeReference(self, S: TopoDS_Shape, AvoidS: TopoDS_Shape) -> TopAbs_State: ...
	@overload
	def StateShapeReference(self, S: TopoDS_Shape, LAvoidS: TopTools_ListOfShape) -> TopAbs_State: ...
	@overload
	def StateShapeShape(self, S: TopoDS_Shape, SRef: TopoDS_Shape, samedomain: Optional[int] = 0) -> TopAbs_State: ...
	@overload
	def StateShapeShape(self, S: TopoDS_Shape, AvoidS: TopoDS_Shape, SRef: TopoDS_Shape) -> TopAbs_State: ...
	@overload
	def StateShapeShape(self, S: TopoDS_Shape, LAvoidS: TopTools_ListOfShape, SRef: TopoDS_Shape) -> TopAbs_State: ...

class TopOpeBRepTool_ShapeExplorer(TopExp_Explorer):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: TopoDS_Shape, ToFind: TopAbs_ShapeEnum, ToAvoid: Optional[TopAbs_ShapeEnum] = TopAbs_SHAPE) -> None: ...
	def Index(self) -> int: ...
	def Init(self, S: TopoDS_Shape, ToFind: TopAbs_ShapeEnum, ToAvoid: Optional[TopAbs_ShapeEnum] = TopAbs_SHAPE) -> None: ...
	def Next(self) -> None: ...

class TopOpeBRepTool_ShapeTool:
	@staticmethod
	def AdjustOnPeriodic(S: TopoDS_Shape) -> Tuple[float, float]: ...
	@overload
	@staticmethod
	def BASISCURVE(C: Geom_Curve) -> Geom_Curve: ...
	@overload
	@staticmethod
	def BASISCURVE(E: TopoDS_Edge) -> Geom_Curve: ...
	@overload
	@staticmethod
	def BASISSURFACE(S: Geom_Surface) -> Geom_Surface: ...
	@overload
	@staticmethod
	def BASISSURFACE(F: TopoDS_Face) -> Geom_Surface: ...
	@staticmethod
	def Closed(S1: TopoDS_Shape, S2: TopoDS_Shape) -> bool: ...
	@staticmethod
	def CurvesSameOriented(C1: BRepAdaptor_Curve, C2: BRepAdaptor_Curve) -> bool: ...
	@overload
	@staticmethod
	def EdgeData(BRAC: BRepAdaptor_Curve, P: float, T: gp_Dir, N: gp_Dir) -> Tuple[float, float]: ...
	@overload
	@staticmethod
	def EdgeData(E: TopoDS_Shape, P: float, T: gp_Dir, N: gp_Dir) -> Tuple[float, float]: ...
	@staticmethod
	def EdgesSameOriented(E1: TopoDS_Shape, E2: TopoDS_Shape) -> bool: ...
	@staticmethod
	def FacesSameOriented(F1: TopoDS_Shape, F2: TopoDS_Shape) -> bool: ...
	@staticmethod
	def PeriodizeParameter(par: float, EE: TopoDS_Shape, FF: TopoDS_Shape) -> float: ...
	@staticmethod
	def Pnt(S: TopoDS_Shape) -> gp_Pnt: ...
	@overload
	@staticmethod
	def Resolution3d(SU: Geom_Surface, Tol2d: float) -> float: ...
	@overload
	@staticmethod
	def Resolution3d(F: TopoDS_Face, Tol2d: float) -> float: ...
	@staticmethod
	def Resolution3dU(SU: Geom_Surface, Tol2d: float) -> float: ...
	@staticmethod
	def Resolution3dV(SU: Geom_Surface, Tol2d: float) -> float: ...
	@staticmethod
	def ShapesSameOriented(S1: TopoDS_Shape, S2: TopoDS_Shape) -> bool: ...
	@staticmethod
	def SurfacesSameOriented(S1: BRepAdaptor_Surface, S2: BRepAdaptor_Surface) -> bool: ...
	@staticmethod
	def Tolerance(S: TopoDS_Shape) -> float: ...
	@overload
	@staticmethod
	def UVBOUNDS(S: Geom_Surface) -> Tuple[bool, bool, float, float, float, float]: ...
	@overload
	@staticmethod
	def UVBOUNDS(F: TopoDS_Face) -> Tuple[bool, bool, float, float, float, float]: ...

class TopOpeBRepTool_SolidClassifier:
	def __init__(self) -> None: ...
	@overload
	def Classify(self, S: TopoDS_Solid, P: gp_Pnt, Tol: float) -> TopAbs_State: ...
	@overload
	def Classify(self, S: TopoDS_Shell, P: gp_Pnt, Tol: float) -> TopAbs_State: ...
	def Clear(self) -> None: ...
	def LoadShell(self, S: TopoDS_Shell) -> None: ...
	def LoadSolid(self, S: TopoDS_Solid) -> None: ...
	def State(self) -> TopAbs_State: ...

class TopOpeBRepTool_TOOL:
	@staticmethod
	def ClosedE(E: TopoDS_Edge, vclo: TopoDS_Vertex) -> bool: ...
	@staticmethod
	def ClosedS(F: TopoDS_Face) -> bool: ...
	@staticmethod
	def CurvE(E: TopoDS_Edge, par: float, tg0: gp_Dir) -> Tuple[bool, float]: ...
	@staticmethod
	def CurvF(F: TopoDS_Face, uv: gp_Pnt2d, tg0: gp_Dir) -> Tuple[bool, float, bool]: ...
	@staticmethod
	def EdgeONFace(par: float, ed: TopoDS_Edge, uv: gp_Pnt2d, fa: TopoDS_Face) -> Tuple[bool, bool]: ...
	@staticmethod
	def Getduv(f: TopoDS_Face, uv: gp_Pnt2d, dir: gp_Vec, factor: float, duv: gp_Dir2d) -> bool: ...
	@staticmethod
	def Getstp3dF(p: gp_Pnt, f: TopoDS_Face, uv: gp_Pnt2d, st: TopAbs_State) -> bool: ...
	@overload
	@staticmethod
	def IsClosingE(E: TopoDS_Edge, F: TopoDS_Face) -> bool: ...
	@overload
	@staticmethod
	def IsClosingE(E: TopoDS_Edge, W: TopoDS_Shape, F: TopoDS_Face) -> bool: ...
	@overload
	@staticmethod
	def IsQuad(E: TopoDS_Edge) -> bool: ...
	@overload
	@staticmethod
	def IsQuad(F: TopoDS_Face) -> bool: ...
	@overload
	@staticmethod
	def IsonCLO(PC: Geom2d_Curve, onU: bool, xfirst: float, xperiod: float, xtol: float) -> bool: ...
	@overload
	@staticmethod
	def IsonCLO(C2DF: TopOpeBRepTool_C2DF, onU: bool, xfirst: float, xperiod: float, xtol: float) -> bool: ...
	@overload
	@staticmethod
	def Matter(d1: gp_Vec, d2: gp_Vec, ref: gp_Vec) -> float: ...
	@overload
	@staticmethod
	def Matter(d1: gp_Vec2d, d2: gp_Vec2d) -> float: ...
	@overload
	@staticmethod
	def Matter(xx1: gp_Dir, nt1: gp_Dir, xx2: gp_Dir, nt2: gp_Dir, tola: float) -> Tuple[bool, float]: ...
	@overload
	@staticmethod
	def Matter(f1: TopoDS_Face, f2: TopoDS_Face, e: TopoDS_Edge, pare: float, tola: float) -> Tuple[bool, float]: ...
	@staticmethod
	def MatterKPtg(f1: TopoDS_Face, f2: TopoDS_Face, e: TopoDS_Edge) -> Tuple[bool, float]: ...
	@staticmethod
	def MkShell(lF: TopTools_ListOfShape, She: TopoDS_Shape) -> None: ...
	@staticmethod
	def NgApp(par: float, E: TopoDS_Edge, F: TopoDS_Face, tola: float, ngApp: gp_Dir) -> bool: ...
	@staticmethod
	def NggeomF(uv: gp_Pnt2d, F: TopoDS_Face, ng: gp_Vec) -> bool: ...
	@staticmethod
	def Nt(uv: gp_Pnt2d, f: TopoDS_Face, normt: gp_Dir) -> bool: ...
	@staticmethod
	def OnBoundary(par: float, E: TopoDS_Edge) -> int: ...
	@staticmethod
	def OriinSor(sub: TopoDS_Shape, S: TopoDS_Shape, checkclo: Optional[bool] = False) -> int: ...
	@staticmethod
	def OriinSorclosed(sub: TopoDS_Shape, S: TopoDS_Shape) -> int: ...
	@staticmethod
	def ParE(Iv: int, E: TopoDS_Edge) -> float: ...
	@staticmethod
	def ParE2d(p2d: gp_Pnt2d, e: TopoDS_Edge, f: TopoDS_Face) -> Tuple[bool, float, float]: ...
	@staticmethod
	def ParISO(p2d: gp_Pnt2d, e: TopoDS_Edge, f: TopoDS_Face) -> Tuple[bool, float]: ...
	@staticmethod
	def Remove(loS: TopTools_ListOfShape, toremove: TopoDS_Shape) -> bool: ...
	@staticmethod
	def SplitE(Eanc: TopoDS_Edge, Splits: TopTools_ListOfShape) -> bool: ...
	@staticmethod
	def Tg2d(iv: int, E: TopoDS_Edge, C2DF: TopOpeBRepTool_C2DF) -> gp_Vec2d: ...
	@staticmethod
	def Tg2dApp(iv: int, E: TopoDS_Edge, C2DF: TopOpeBRepTool_C2DF, factor: float) -> gp_Vec2d: ...
	@staticmethod
	def TgINSIDE(v: TopoDS_Vertex, E: TopoDS_Edge, Tg: gp_Vec) -> Tuple[bool, int]: ...
	@overload
	@staticmethod
	def TggeomE(par: float, BC: BRepAdaptor_Curve, Tg: gp_Vec) -> bool: ...
	@overload
	@staticmethod
	def TggeomE(par: float, E: TopoDS_Edge, Tg: gp_Vec) -> bool: ...
	@staticmethod
	def TolP(E: TopoDS_Edge, F: TopoDS_Face) -> float: ...
	@staticmethod
	def TolUV(F: TopoDS_Face, tol3d: float) -> float: ...
	@staticmethod
	def TrslUV(t2d: gp_Vec2d, C2DF: TopOpeBRepTool_C2DF) -> None: ...
	@staticmethod
	def TrslUVModifE(t2d: gp_Vec2d, F: TopoDS_Face, E: TopoDS_Edge) -> bool: ...
	@staticmethod
	def UVF(par: float, C2DF: TopOpeBRepTool_C2DF) -> gp_Pnt2d: ...
	@overload
	@staticmethod
	def UVISO(PC: Geom2d_Curve, d2d: gp_Dir2d, o2d: gp_Pnt2d) -> Tuple[bool, bool, bool]: ...
	@overload
	@staticmethod
	def UVISO(C2DF: TopOpeBRepTool_C2DF, d2d: gp_Dir2d, o2d: gp_Pnt2d) -> Tuple[bool, bool, bool]: ...
	@overload
	@staticmethod
	def UVISO(E: TopoDS_Edge, F: TopoDS_Face, d2d: gp_Dir2d, o2d: gp_Pnt2d) -> Tuple[bool, bool, bool]: ...
	@staticmethod
	def Vertex(Iv: int, E: TopoDS_Edge) -> TopoDS_Vertex: ...
	@staticmethod
	def Vertices(E: TopoDS_Edge, Vces: TopTools_Array1OfShape) -> None: ...
	@staticmethod
	def WireToFace(Fref: TopoDS_Face, mapWlow: TopTools_DataMapOfShapeListOfShape, lFs: TopTools_ListOfShape) -> bool: ...
	@staticmethod
	def XX(uv: gp_Pnt2d, f: TopoDS_Face, par: float, e: TopoDS_Edge, xx: gp_Dir) -> bool: ...
	@staticmethod
	def minDUV(F: TopoDS_Face) -> float: ...
	@staticmethod
	def outUVbounds(uv: gp_Pnt2d, F: TopoDS_Face) -> bool: ...
	@staticmethod
	def stuvF(uv: gp_Pnt2d, F: TopoDS_Face) -> Tuple[int, int]: ...
	@staticmethod
	def tryNgApp(par: float, E: TopoDS_Edge, F: TopoDS_Face, tola: float, ng: gp_Dir) -> bool: ...
	@staticmethod
	def tryOriEinF(par: float, E: TopoDS_Edge, F: TopoDS_Face) -> int: ...
	@staticmethod
	def tryTg2dApp(iv: int, E: TopoDS_Edge, C2DF: TopOpeBRepTool_C2DF, factor: float) -> gp_Vec2d: ...
	@staticmethod
	def uvApp(f: TopoDS_Face, e: TopoDS_Edge, par: float, eps: float, uvapp: gp_Pnt2d) -> bool: ...

class TopOpeBRepTool_connexity:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Key: TopoDS_Shape) -> None: ...
	@overload
	def AddItem(self, OriKey: int, Item: TopTools_ListOfShape) -> None: ...
	@overload
	def AddItem(self, OriKey: int, Item: TopoDS_Shape) -> None: ...
	def AllItems(self, Item: TopTools_ListOfShape) -> int: ...
	def ChangeItem(self, OriKey: int) -> TopTools_ListOfShape: ...
	def IsFaulty(self) -> bool: ...
	def IsInternal(self, Item: TopTools_ListOfShape) -> int: ...
	def IsMultiple(self) -> bool: ...
	def Item(self, OriKey: int, Item: TopTools_ListOfShape) -> int: ...
	def Key(self) -> TopoDS_Shape: ...
	@overload
	def RemoveItem(self, OriKey: int, Item: TopoDS_Shape) -> bool: ...
	@overload
	def RemoveItem(self, Item: TopoDS_Shape) -> bool: ...
	def SetKey(self, Key: TopoDS_Shape) -> None: ...

class TopOpeBRepTool_face:
	def __init__(self) -> None: ...
	def Ffinite(self) -> TopoDS_Face: ...
	def Finite(self) -> bool: ...
	def Init(self, W: TopoDS_Wire, Fref: TopoDS_Face) -> bool: ...
	def IsDone(self) -> bool: ...
	def RealF(self) -> TopoDS_Face: ...
	def W(self) -> TopoDS_Wire: ...

class TopOpeBRepTool_makeTransition:
	def __init__(self) -> None: ...
	def Getfactor(self) -> float: ...
	def HasRest(self) -> bool: ...
	def Initialize(self, E: TopoDS_Edge, pbef: float, paft: float, parE: float, FS: TopoDS_Face, uv: gp_Pnt2d, factor: float) -> bool: ...
	def IsT2d(self) -> bool: ...
	def MkT2donE(self, stb: TopAbs_State, sta: TopAbs_State) -> bool: ...
	def MkT3dproj(self, stb: TopAbs_State, sta: TopAbs_State) -> bool: ...
	def MkT3onE(self, stb: TopAbs_State, sta: TopAbs_State) -> bool: ...
	def MkTonE(self, stb: TopAbs_State, sta: TopAbs_State) -> bool: ...
	def SetRest(self, ES: TopoDS_Edge, parES: float) -> bool: ...
	def Setfactor(self, factor: float) -> None: ...

#classnotwrapped
class TopOpeBRepTool_STATE: ...

#classnotwrapped
class TopOpeBRepTool_mkTondgE: ...

# harray1 classes
# harray2 classes
# hsequence classes

topopebreptool_CorrectONUVISO = topopebreptool.CorrectONUVISO
topopebreptool_MakeFaces = topopebreptool.MakeFaces
topopebreptool_Print = topopebreptool.Print
topopebreptool_PurgeClosingEdges = topopebreptool.PurgeClosingEdges
topopebreptool_PurgeClosingEdges = topopebreptool.PurgeClosingEdges
topopebreptool_Regularize = topopebreptool.Regularize
topopebreptool_RegularizeFace = topopebreptool.RegularizeFace
topopebreptool_RegularizeShells = topopebreptool.RegularizeShells
topopebreptool_RegularizeWires = topopebreptool.RegularizeWires
TopOpeBRepTool_AncestorsTool_MakeAncestors = TopOpeBRepTool_AncestorsTool.MakeAncestors
TopOpeBRepTool_BoxSort_MakeHABCOB = TopOpeBRepTool_BoxSort.MakeHABCOB
TopOpeBRepTool_CurveTool_IsProjectable = TopOpeBRepTool_CurveTool.IsProjectable
TopOpeBRepTool_CurveTool_MakeBSpline1fromPnt = TopOpeBRepTool_CurveTool.MakeBSpline1fromPnt
TopOpeBRepTool_CurveTool_MakeBSpline1fromPnt2d = TopOpeBRepTool_CurveTool.MakeBSpline1fromPnt2d
TopOpeBRepTool_CurveTool_MakePCurveOnFace = TopOpeBRepTool_CurveTool.MakePCurveOnFace
TopOpeBRepTool_HBoxTool_ComputeBox = TopOpeBRepTool_HBoxTool.ComputeBox
TopOpeBRepTool_HBoxTool_ComputeBoxOnVertices = TopOpeBRepTool_HBoxTool.ComputeBoxOnVertices
TopOpeBRepTool_HBoxTool_DumpB = TopOpeBRepTool_HBoxTool.DumpB
TopOpeBRepTool_REGUS_SplitF = TopOpeBRepTool_REGUS.SplitF
TopOpeBRepTool_REGUS_WireToFace = TopOpeBRepTool_REGUS.WireToFace
TopOpeBRepTool_ShapeTool_AdjustOnPeriodic = TopOpeBRepTool_ShapeTool.AdjustOnPeriodic
TopOpeBRepTool_ShapeTool_BASISCURVE = TopOpeBRepTool_ShapeTool.BASISCURVE
TopOpeBRepTool_ShapeTool_BASISCURVE = TopOpeBRepTool_ShapeTool.BASISCURVE
TopOpeBRepTool_ShapeTool_BASISSURFACE = TopOpeBRepTool_ShapeTool.BASISSURFACE
TopOpeBRepTool_ShapeTool_BASISSURFACE = TopOpeBRepTool_ShapeTool.BASISSURFACE
TopOpeBRepTool_ShapeTool_Closed = TopOpeBRepTool_ShapeTool.Closed
TopOpeBRepTool_ShapeTool_CurvesSameOriented = TopOpeBRepTool_ShapeTool.CurvesSameOriented
TopOpeBRepTool_ShapeTool_EdgeData = TopOpeBRepTool_ShapeTool.EdgeData
TopOpeBRepTool_ShapeTool_EdgeData = TopOpeBRepTool_ShapeTool.EdgeData
TopOpeBRepTool_ShapeTool_EdgesSameOriented = TopOpeBRepTool_ShapeTool.EdgesSameOriented
TopOpeBRepTool_ShapeTool_FacesSameOriented = TopOpeBRepTool_ShapeTool.FacesSameOriented
TopOpeBRepTool_ShapeTool_PeriodizeParameter = TopOpeBRepTool_ShapeTool.PeriodizeParameter
TopOpeBRepTool_ShapeTool_Pnt = TopOpeBRepTool_ShapeTool.Pnt
TopOpeBRepTool_ShapeTool_Resolution3d = TopOpeBRepTool_ShapeTool.Resolution3d
TopOpeBRepTool_ShapeTool_Resolution3d = TopOpeBRepTool_ShapeTool.Resolution3d
TopOpeBRepTool_ShapeTool_Resolution3dU = TopOpeBRepTool_ShapeTool.Resolution3dU
TopOpeBRepTool_ShapeTool_Resolution3dV = TopOpeBRepTool_ShapeTool.Resolution3dV
TopOpeBRepTool_ShapeTool_ShapesSameOriented = TopOpeBRepTool_ShapeTool.ShapesSameOriented
TopOpeBRepTool_ShapeTool_SurfacesSameOriented = TopOpeBRepTool_ShapeTool.SurfacesSameOriented
TopOpeBRepTool_ShapeTool_Tolerance = TopOpeBRepTool_ShapeTool.Tolerance
TopOpeBRepTool_ShapeTool_UVBOUNDS = TopOpeBRepTool_ShapeTool.UVBOUNDS
TopOpeBRepTool_ShapeTool_UVBOUNDS = TopOpeBRepTool_ShapeTool.UVBOUNDS
TopOpeBRepTool_TOOL_ClosedE = TopOpeBRepTool_TOOL.ClosedE
TopOpeBRepTool_TOOL_ClosedS = TopOpeBRepTool_TOOL.ClosedS
TopOpeBRepTool_TOOL_CurvE = TopOpeBRepTool_TOOL.CurvE
TopOpeBRepTool_TOOL_CurvF = TopOpeBRepTool_TOOL.CurvF
TopOpeBRepTool_TOOL_EdgeONFace = TopOpeBRepTool_TOOL.EdgeONFace
TopOpeBRepTool_TOOL_Getduv = TopOpeBRepTool_TOOL.Getduv
TopOpeBRepTool_TOOL_Getstp3dF = TopOpeBRepTool_TOOL.Getstp3dF
TopOpeBRepTool_TOOL_IsClosingE = TopOpeBRepTool_TOOL.IsClosingE
TopOpeBRepTool_TOOL_IsClosingE = TopOpeBRepTool_TOOL.IsClosingE
TopOpeBRepTool_TOOL_IsQuad = TopOpeBRepTool_TOOL.IsQuad
TopOpeBRepTool_TOOL_IsQuad = TopOpeBRepTool_TOOL.IsQuad
TopOpeBRepTool_TOOL_IsonCLO = TopOpeBRepTool_TOOL.IsonCLO
TopOpeBRepTool_TOOL_IsonCLO = TopOpeBRepTool_TOOL.IsonCLO
TopOpeBRepTool_TOOL_Matter = TopOpeBRepTool_TOOL.Matter
TopOpeBRepTool_TOOL_Matter = TopOpeBRepTool_TOOL.Matter
TopOpeBRepTool_TOOL_Matter = TopOpeBRepTool_TOOL.Matter
TopOpeBRepTool_TOOL_Matter = TopOpeBRepTool_TOOL.Matter
TopOpeBRepTool_TOOL_MatterKPtg = TopOpeBRepTool_TOOL.MatterKPtg
TopOpeBRepTool_TOOL_MkShell = TopOpeBRepTool_TOOL.MkShell
TopOpeBRepTool_TOOL_NgApp = TopOpeBRepTool_TOOL.NgApp
TopOpeBRepTool_TOOL_NggeomF = TopOpeBRepTool_TOOL.NggeomF
TopOpeBRepTool_TOOL_Nt = TopOpeBRepTool_TOOL.Nt
TopOpeBRepTool_TOOL_OnBoundary = TopOpeBRepTool_TOOL.OnBoundary
TopOpeBRepTool_TOOL_OriinSor = TopOpeBRepTool_TOOL.OriinSor
TopOpeBRepTool_TOOL_OriinSorclosed = TopOpeBRepTool_TOOL.OriinSorclosed
TopOpeBRepTool_TOOL_ParE = TopOpeBRepTool_TOOL.ParE
TopOpeBRepTool_TOOL_ParE2d = TopOpeBRepTool_TOOL.ParE2d
TopOpeBRepTool_TOOL_ParISO = TopOpeBRepTool_TOOL.ParISO
TopOpeBRepTool_TOOL_Remove = TopOpeBRepTool_TOOL.Remove
TopOpeBRepTool_TOOL_SplitE = TopOpeBRepTool_TOOL.SplitE
TopOpeBRepTool_TOOL_Tg2d = TopOpeBRepTool_TOOL.Tg2d
TopOpeBRepTool_TOOL_Tg2dApp = TopOpeBRepTool_TOOL.Tg2dApp
TopOpeBRepTool_TOOL_TgINSIDE = TopOpeBRepTool_TOOL.TgINSIDE
TopOpeBRepTool_TOOL_TggeomE = TopOpeBRepTool_TOOL.TggeomE
TopOpeBRepTool_TOOL_TggeomE = TopOpeBRepTool_TOOL.TggeomE
TopOpeBRepTool_TOOL_TolP = TopOpeBRepTool_TOOL.TolP
TopOpeBRepTool_TOOL_TolUV = TopOpeBRepTool_TOOL.TolUV
TopOpeBRepTool_TOOL_TrslUV = TopOpeBRepTool_TOOL.TrslUV
TopOpeBRepTool_TOOL_TrslUVModifE = TopOpeBRepTool_TOOL.TrslUVModifE
TopOpeBRepTool_TOOL_UVF = TopOpeBRepTool_TOOL.UVF
TopOpeBRepTool_TOOL_UVISO = TopOpeBRepTool_TOOL.UVISO
TopOpeBRepTool_TOOL_UVISO = TopOpeBRepTool_TOOL.UVISO
TopOpeBRepTool_TOOL_UVISO = TopOpeBRepTool_TOOL.UVISO
TopOpeBRepTool_TOOL_Vertex = TopOpeBRepTool_TOOL.Vertex
TopOpeBRepTool_TOOL_Vertices = TopOpeBRepTool_TOOL.Vertices
TopOpeBRepTool_TOOL_WireToFace = TopOpeBRepTool_TOOL.WireToFace
TopOpeBRepTool_TOOL_XX = TopOpeBRepTool_TOOL.XX
TopOpeBRepTool_TOOL_minDUV = TopOpeBRepTool_TOOL.minDUV
TopOpeBRepTool_TOOL_outUVbounds = TopOpeBRepTool_TOOL.outUVbounds
TopOpeBRepTool_TOOL_stuvF = TopOpeBRepTool_TOOL.stuvF
TopOpeBRepTool_TOOL_tryNgApp = TopOpeBRepTool_TOOL.tryNgApp
TopOpeBRepTool_TOOL_tryOriEinF = TopOpeBRepTool_TOOL.tryOriEinF
TopOpeBRepTool_TOOL_tryTg2dApp = TopOpeBRepTool_TOOL.tryTg2dApp
TopOpeBRepTool_TOOL_uvApp = TopOpeBRepTool_TOOL.uvApp



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Units import *


class UnitsAPI_SystemUnits(IntEnum):
	UnitsAPI_DEFAULT: int = ...
	UnitsAPI_SI: int = ...
	UnitsAPI_MDTV: int = ...
UnitsAPI_DEFAULT = UnitsAPI_SystemUnits.UnitsAPI_DEFAULT
UnitsAPI_SI = UnitsAPI_SystemUnits.UnitsAPI_SI
UnitsAPI_MDTV = UnitsAPI_SystemUnits.UnitsAPI_MDTV

class unitsapi:
	@staticmethod
	def AnyFromLS(aData: float, aUnit: str) -> float: ...
	@staticmethod
	def AnyFromSI(aData: float, aUnit: str) -> float: ...
	@staticmethod
	def AnyToAny(aData: float, aUnit1: str, aUnit2: str) -> float: ...
	@overload
	@staticmethod
	def AnyToLS(aData: float, aUnit: str) -> float: ...
	@overload
	@staticmethod
	def AnyToLS(aData: float, aUnit: str, aDim: Units_Dimensions) -> float: ...
	@overload
	@staticmethod
	def AnyToSI(aData: float, aUnit: str) -> float: ...
	@overload
	@staticmethod
	def AnyToSI(aData: float, aUnit: str, aDim: Units_Dimensions) -> float: ...
	@staticmethod
	def Check(aQuantity: str, aUnit: str) -> bool: ...
	@staticmethod
	def CurrentFromAny(aData: float, aQuantity: str, aUnit: str) -> float: ...
	@staticmethod
	def CurrentFromLS(aData: float, aQuantity: str) -> float: ...
	@staticmethod
	def CurrentFromSI(aData: float, aQuantity: str) -> float: ...
	@staticmethod
	def CurrentToAny(aData: float, aQuantity: str, aUnit: str) -> float: ...
	@staticmethod
	def CurrentToLS(aData: float, aQuantity: str) -> float: ...
	@staticmethod
	def CurrentToSI(aData: float, aQuantity: str) -> float: ...
	@staticmethod
	def CurrentUnit(aQuantity: str) -> str: ...
	@staticmethod
	def DimensionAmountOfSubstance() -> Units_Dimensions: ...
	@staticmethod
	def DimensionElectricCurrent() -> Units_Dimensions: ...
	@staticmethod
	def DimensionLength() -> Units_Dimensions: ...
	@staticmethod
	def DimensionLess() -> Units_Dimensions: ...
	@staticmethod
	def DimensionLuminousIntensity() -> Units_Dimensions: ...
	@staticmethod
	def DimensionMass() -> Units_Dimensions: ...
	@staticmethod
	def DimensionPlaneAngle() -> Units_Dimensions: ...
	@staticmethod
	def DimensionSolidAngle() -> Units_Dimensions: ...
	@staticmethod
	def DimensionThermodynamicTemperature() -> Units_Dimensions: ...
	@staticmethod
	def DimensionTime() -> Units_Dimensions: ...
	@staticmethod
	def Dimensions(aQuantity: str) -> Units_Dimensions: ...
	@staticmethod
	def LSToSI(aData: float, aQuantity: str) -> float: ...
	@staticmethod
	def LocalSystem() -> UnitsAPI_SystemUnits: ...
	@staticmethod
	def Reload() -> None: ...
	@staticmethod
	def SIToLS(aData: float, aQuantity: str) -> float: ...
	@staticmethod
	def Save() -> None: ...
	@staticmethod
	def SetCurrentUnit(aQuantity: str, aUnit: str) -> None: ...
	@staticmethod
	def SetLocalSystem(aSystemUnit: Optional[UnitsAPI_SystemUnits] = UnitsAPI_SI) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

unitsapi_AnyFromLS = unitsapi.AnyFromLS
unitsapi_AnyFromSI = unitsapi.AnyFromSI
unitsapi_AnyToAny = unitsapi.AnyToAny
unitsapi_AnyToLS = unitsapi.AnyToLS
unitsapi_AnyToLS = unitsapi.AnyToLS
unitsapi_AnyToSI = unitsapi.AnyToSI
unitsapi_AnyToSI = unitsapi.AnyToSI
unitsapi_Check = unitsapi.Check
unitsapi_CurrentFromAny = unitsapi.CurrentFromAny
unitsapi_CurrentFromLS = unitsapi.CurrentFromLS
unitsapi_CurrentFromSI = unitsapi.CurrentFromSI
unitsapi_CurrentToAny = unitsapi.CurrentToAny
unitsapi_CurrentToLS = unitsapi.CurrentToLS
unitsapi_CurrentToSI = unitsapi.CurrentToSI
unitsapi_CurrentUnit = unitsapi.CurrentUnit
unitsapi_DimensionAmountOfSubstance = unitsapi.DimensionAmountOfSubstance
unitsapi_DimensionElectricCurrent = unitsapi.DimensionElectricCurrent
unitsapi_DimensionLength = unitsapi.DimensionLength
unitsapi_DimensionLess = unitsapi.DimensionLess
unitsapi_DimensionLuminousIntensity = unitsapi.DimensionLuminousIntensity
unitsapi_DimensionMass = unitsapi.DimensionMass
unitsapi_DimensionPlaneAngle = unitsapi.DimensionPlaneAngle
unitsapi_DimensionSolidAngle = unitsapi.DimensionSolidAngle
unitsapi_DimensionThermodynamicTemperature = unitsapi.DimensionThermodynamicTemperature
unitsapi_DimensionTime = unitsapi.DimensionTime
unitsapi_Dimensions = unitsapi.Dimensions
unitsapi_LSToSI = unitsapi.LSToSI
unitsapi_LocalSystem = unitsapi.LocalSystem
unitsapi_Reload = unitsapi.Reload
unitsapi_SIToLS = unitsapi.SIToLS
unitsapi_Save = unitsapi.Save
unitsapi_SetCurrentUnit = unitsapi.SetCurrentUnit
unitsapi_SetLocalSystem = unitsapi.SetLocalSystem



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
ShapeBuild module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_shapebuild.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _ShapeBuild
else:
    import _ShapeBuild

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _ShapeBuild.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _ShapeBuild.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _ShapeBuild.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _ShapeBuild.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _ShapeBuild.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _ShapeBuild.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _ShapeBuild.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _ShapeBuild.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _ShapeBuild.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _ShapeBuild.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _ShapeBuild.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _ShapeBuild.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _ShapeBuild.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _ShapeBuild.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _ShapeBuild.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _ShapeBuild.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _ShapeBuild.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _ShapeBuild:
_ShapeBuild.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _ShapeBuild.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.Geom
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.TopoDS
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.Geom2d
import OCC.Core.BRepTools
import OCC.Core.Bnd
import OCC.Core.BVH
import OCC.Core.TopTools
import OCC.Core.BRep
import OCC.Core.Poly
import OCC.Core.TShort
import OCC.Core.ShapeExtend
import OCC.Core.TColGeom

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_ShapeBuild_ReShape_Create() -> "opencascade::handle< ShapeBuild_ReShape >":
    return _ShapeBuild.Handle_ShapeBuild_ReShape_Create()

def Handle_ShapeBuild_ReShape_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< ShapeBuild_ReShape >":
    return _ShapeBuild.Handle_ShapeBuild_ReShape_DownCast(t)

def Handle_ShapeBuild_ReShape_IsNull(t: "opencascade::handle< ShapeBuild_ReShape > const &") -> "bool":
    return _ShapeBuild.Handle_ShapeBuild_ReShape_IsNull(t)
class shapebuild(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def PlaneXOY(*args) -> "opencascade::handle< Geom_Plane >":
        r"""
        Rebuilds a shape with substitution of some components returns a geom_surface which is the plane xoy (z positive) this allows to consider an uv space homologous to a 3d space, with this support surface.

        Returns
        -------
        opencascade::handle<Geom_Plane>

        """
        return _ShapeBuild.shapebuild_PlaneXOY(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _ShapeBuild.shapebuild_swiginit(self, _ShapeBuild.new_shapebuild())
    __swig_destroy__ = _ShapeBuild.delete_shapebuild

# Register shapebuild in _ShapeBuild:
_ShapeBuild.shapebuild_swigregister(shapebuild)

def shapebuild_PlaneXOY(*args) -> "opencascade::handle< Geom_Plane >":
    r"""
    Rebuilds a shape with substitution of some components returns a geom_surface which is the plane xoy (z positive) this allows to consider an uv space homologous to a 3d space, with this support surface.

    Returns
    -------
    opencascade::handle<Geom_Plane>

    """
    return _ShapeBuild.shapebuild_PlaneXOY(*args)

class ShapeBuild_Edge(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def BuildCurve3d(self, *args) -> "Standard_Boolean":
        r"""
        Calls breptools::buildcurve3d.

        Parameters
        ----------
        edge: TopoDS_Edge

        Returns
        -------
        bool

        """
        return _ShapeBuild.ShapeBuild_Edge_BuildCurve3d(self, *args)

    def Copy(self, *args) -> "TopoDS_Edge":
        r"""
        Make a copy of <edge> by call to copyreplacevertices() (i.e. construct new tedge with the same pcurves and vertices). if <sharepcurves> is false, pcurves are also replaced by their copies with help of method copypcurves.

        Parameters
        ----------
        edge: TopoDS_Edge
        sharepcurves: bool,optional
        	default value is Standard_True

        Returns
        -------
        TopoDS_Edge

        """
        return _ShapeBuild.ShapeBuild_Edge_Copy(self, *args)

    def CopyPCurves(self, *args) -> "void":
        r"""
        Makes a copy of pcurves from edge <fromedge> into edge <toedge>. pcurves which are already present in <toedge>, are replaced by copies, other are copied. ranges are also copied.

        Parameters
        ----------
        toedge: TopoDS_Edge
        fromedge: TopoDS_Edge

        Returns
        -------
        None

        """
        return _ShapeBuild.ShapeBuild_Edge_CopyPCurves(self, *args)

    def CopyRanges(self, *args) -> "void":
        r"""
        Copies ranges for curve3d and all common pcurves from edge <fromedge> into edge <toedge>.

        Parameters
        ----------
        toedge: TopoDS_Edge
        fromedge: TopoDS_Edge
        alpha: float,optional
        	default value is 0
        beta: float,optional
        	default value is 1

        Returns
        -------
        None

        """
        return _ShapeBuild.ShapeBuild_Edge_CopyRanges(self, *args)

    def CopyReplaceVertices(self, *args) -> "TopoDS_Edge":
        r"""
        Copy edge and replace one or both its vertices to a given one(s). vertex v1 replaces forward vertex, and v2 - reversed, as they are found by topods_iterator. if v1 or v2 is null, the original vertex is taken.

        Parameters
        ----------
        edge: TopoDS_Edge
        V1: TopoDS_Vertex
        V2: TopoDS_Vertex

        Returns
        -------
        TopoDS_Edge

        """
        return _ShapeBuild.ShapeBuild_Edge_CopyReplaceVertices(self, *args)

    def MakeEdge(self, *args) -> "void":
        r"""
        Makes edge with curve and location.

        Parameters
        ----------
        edge: TopoDS_Edge
        curve: Geom_Curve
        L: TopLoc_Location

        Returns
        -------
        None
        Makes edge with curve, location and range [p1, p2].

        Parameters
        ----------
        edge: TopoDS_Edge
        curve: Geom_Curve
        L: TopLoc_Location
        p1: float
        p2: float

        Returns
        -------
        None
        Makes edge with pcurve and face.

        Parameters
        ----------
        edge: TopoDS_Edge
        pcurve: Geom2d_Curve
        face: TopoDS_Face

        Returns
        -------
        None
        Makes edge with pcurve, face and range [p1, p2].

        Parameters
        ----------
        edge: TopoDS_Edge
        pcurve: Geom2d_Curve
        face: TopoDS_Face
        p1: float
        p2: float

        Returns
        -------
        None
        Makes edge with pcurve, surface and location.

        Parameters
        ----------
        edge: TopoDS_Edge
        pcurve: Geom2d_Curve
        S: Geom_Surface
        L: TopLoc_Location

        Returns
        -------
        None
        Makes edge with pcurve, surface, location and range [p1, p2].

        Parameters
        ----------
        edge: TopoDS_Edge
        pcurve: Geom2d_Curve
        S: Geom_Surface
        L: TopLoc_Location
        p1: float
        p2: float

        Returns
        -------
        None

        """
        return _ShapeBuild.ShapeBuild_Edge_MakeEdge(self, *args)

    def ReassignPCurve(self, *args) -> "Standard_Boolean":
        r"""
        Reassign edge pcurve lying on face <old> to another face <sub>. if edge has two pcurves on <old> face, only one of them will be reassigned, and other will left alone. similarly, if edge already had a pcurve on face <sub>, it will have two pcurves on it. returns true if succeeded, false if no pcurve lying on <old> found.

        Parameters
        ----------
        edge: TopoDS_Edge
        old: TopoDS_Face
        sub: TopoDS_Face

        Returns
        -------
        bool

        """
        return _ShapeBuild.ShapeBuild_Edge_ReassignPCurve(self, *args)

    def RemoveCurve3d(self, *args) -> "void":
        r"""
        Removes the curve3d recorded in an edge.

        Parameters
        ----------
        edge: TopoDS_Edge

        Returns
        -------
        None

        """
        return _ShapeBuild.ShapeBuild_Edge_RemoveCurve3d(self, *args)

    def RemovePCurve(self, *args) -> "void":
        r"""
        Removes the pcurve(s) which could be recorded in an edge for the given face.

        Parameters
        ----------
        edge: TopoDS_Edge
        face: TopoDS_Face

        Returns
        -------
        None
        Removes the pcurve(s) which could be recorded in an edge for the given surface.

        Parameters
        ----------
        edge: TopoDS_Edge
        surf: Geom_Surface

        Returns
        -------
        None
        Removes the pcurve(s) which could be recorded in an edge for the given surface, with given location.

        Parameters
        ----------
        edge: TopoDS_Edge
        surf: Geom_Surface
        loc: TopLoc_Location

        Returns
        -------
        None

        """
        return _ShapeBuild.ShapeBuild_Edge_RemovePCurve(self, *args)

    def ReplacePCurve(self, *args) -> "void":
        r"""
        Replace the pcurve in an edge for the given face in case if edge is seam, i.e. has 2 pcurves on that face, only pcurve corresponding to the orientation of the edge is replaced.

        Parameters
        ----------
        edge: TopoDS_Edge
        pcurve: Geom2d_Curve
        face: TopoDS_Face

        Returns
        -------
        None

        """
        return _ShapeBuild.ShapeBuild_Edge_ReplacePCurve(self, *args)

    def SetRange3d(self, *args) -> "void":
        r"""
        Sets range on 3d curve only.

        Parameters
        ----------
        edge: TopoDS_Edge
        first: float
        last: float

        Returns
        -------
        None

        """
        return _ShapeBuild.ShapeBuild_Edge_SetRange3d(self, *args)

    def TransformPCurve(self, *args) -> "opencascade::handle< Geom2d_Curve >":
        r"""
        Transforms the pcurve with given matrix and affinity u factor.

        Parameters
        ----------
        pcurve: Geom2d_Curve
        trans: gp_Trsf2d
        uFact: float

        Returns
        -------
        aFirst: float
        aLast: float

        """
        return _ShapeBuild.ShapeBuild_Edge_TransformPCurve(self, *args)

    __repr__ = _dumps_object


    def __init__(self):
        _ShapeBuild.ShapeBuild_Edge_swiginit(self, _ShapeBuild.new_ShapeBuild_Edge())
    __swig_destroy__ = _ShapeBuild.delete_ShapeBuild_Edge

# Register ShapeBuild_Edge in _ShapeBuild:
_ShapeBuild.ShapeBuild_Edge_swigregister(ShapeBuild_Edge)

class ShapeBuild_ReShape(OCC.Core.BRepTools.BRepTools_ReShape):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns an empty reshape.

        Returns
        -------
        None

        """
        _ShapeBuild.ShapeBuild_ReShape_swiginit(self, _ShapeBuild.new_ShapeBuild_ReShape(*args))

    def Apply(self, *args) -> "TopoDS_Shape":
        r"""
        Applies the substitutions requests to a shape //! <until> gives the level of type until which requests are taken into account. for subshapes of the type <until> no rebuild and futher exploring are done. actually, not implemented below topabs_face //! <buildmode> says how to do on a solid,shell ... if one of its sub-shapes has been changed: 0: at least one replace or remove -> compound, else as such 1: at least one remove (replace are ignored) -> compound 2: replace and remove are both ignored if replace/remove are ignored or absent, the result as same type as the starting shape.

        Parameters
        ----------
        shape: TopoDS_Shape
        until: TopAbs_ShapeEnum
        buildmode: int

        Returns
        -------
        TopoDS_Shape
        Applies the substitutions requests to a shape. //! <until> gives the level of type until which requests are taken into account. for subshapes of the type <until> no rebuild and futher exploring are done. //! note: each subshape can be replaced by shape of the same type or by shape containing only shapes of that type (for example, topods_edge can be replaced by topods_edge, topods_wire or topods_compound containing topods_edges). if incompatible shape type is encountered, it is ignored and flag fail1 is set in status.

        Parameters
        ----------
        shape: TopoDS_Shape
        until: TopAbs_ShapeEnum,optional
        	default value is TopAbs_SHAPE

        Returns
        -------
        TopoDS_Shape

        """
        return _ShapeBuild.ShapeBuild_ReShape_Apply(self, *args)

    def Status(self, *args) -> "Standard_Boolean":
        r"""
        Returns a complete substitution status for a shape 0 : not recorded, <newsh> = original <shape> < 0: to be removed, <newsh> is null > 0: to be replaced, <newsh> is a new item if <last> is false, returns status and new shape recorded in the map directly for the shape, if true and status > 0 then recursively searches for the last status and new shape.

        Parameters
        ----------
        shape: TopoDS_Shape
        newsh: TopoDS_Shape
        last: bool,optional
        	default value is Standard_False

        Returns
        -------
        int
        Queries the status of last call to apply(shape,enum) ok : no (sub)shapes replaced or removed done1: source (starting) shape replaced done2: source (starting) shape removed done3: some subshapes replaced done4: some subshapes removed fail1: some replacements not done because of bad type of subshape.

        Parameters
        ----------
        status: ShapeExtend_Status

        Returns
        -------
        bool

        """
        return _ShapeBuild.ShapeBuild_ReShape_Status(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_ShapeBuild_ReShape_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _ShapeBuild.delete_ShapeBuild_ReShape

# Register ShapeBuild_ReShape in _ShapeBuild:
_ShapeBuild.ShapeBuild_ReShape_swigregister(ShapeBuild_ReShape)

class ShapeBuild_Vertex(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def CombineVertex(self, *args) -> "TopoDS_Vertex":
        r"""
        Combines new vertex from two others. this new one is the smallest vertex which comprises both of the source vertices. the function takes into account the positions and tolerances of the source vertices. the tolerance of the new vertex will be equal to the minimal tolerance that is required to comprise source vertices multiplied by tolfactor (in order to avoid errors because of discreteness of calculations).

        Parameters
        ----------
        V1: TopoDS_Vertex
        V2: TopoDS_Vertex
        tolFactor: float,optional
        	default value is 1.0001

        Returns
        -------
        TopoDS_Vertex
        The same function as above, except that it accepts two points and two tolerances instead of vertices.

        Parameters
        ----------
        pnt1: gp_Pnt
        pnt2: gp_Pnt
        tol1: float
        tol2: float
        tolFactor: float,optional
        	default value is 1.0001

        Returns
        -------
        TopoDS_Vertex

        """
        return _ShapeBuild.ShapeBuild_Vertex_CombineVertex(self, *args)

    __repr__ = _dumps_object


    def __init__(self):
        _ShapeBuild.ShapeBuild_Vertex_swiginit(self, _ShapeBuild.new_ShapeBuild_Vertex())
    __swig_destroy__ = _ShapeBuild.delete_ShapeBuild_Vertex

# Register ShapeBuild_Vertex in _ShapeBuild:
_ShapeBuild.ShapeBuild_Vertex_swigregister(ShapeBuild_Vertex)





